@@ -128,14 +128,14 @@ class ContentManager:
             body = f.read()
         if filename.endswith('.css'):
             content_type = 'text/css'
-        elif filename.endswith('.svg'):
+        elif filename.endswith('.svg') or filename.endswith('.svgz')
             content_type = 'image/svg+xml'
         elif filename.endswith('.js') or filename.endswith('.mjs'):
             content_type = 'text/javascript'
         else:
             content_type = self.__magic.from_buffer(body)
 
-        print(f'[{filename}]: Was {content_type}')
+        print(f'[{filename}]: Was {content_type} {type(body)}')
         isBase64Encoded = False
         if content_type.startswith('image/'):
             if self.__app.current_request:
@@ -143,8 +143,9 @@ class ContentManager:
                 if accepts:
                     body = self.convert_by_accepts(body, accepts)
                     content_type = self.__magic.from_buffer(body)
-            isBase64Encoded = True
-        print(f'[{filename}]: Is {content_type}')
+            if not content_type == 'image/svg+xml':
+                isBase64Encoded = True
+        print(f'[{filename}]: Is {content_type} {type(body)}')
         h["Content-Type"] = content_type
         r = ResponseWithBinary(body=body, status_code=status_code, headers=h)
         r.isBase64Encoded = isBase64Encoded
